@@ -95,7 +95,7 @@ define!({
         SimpleBlock(SimpleBlock),
         Dimension(Dimension),
         Number(Number),
-        Percent(Percent),
+        Percentage(Percentage),
         Ratio(Ratio),
         Color(Color),
         Ident(Ident),
@@ -196,7 +196,7 @@ define!({
         pub unit: Ident,
     }
 
-    pub struct Percent {
+    pub struct Percentage {
         pub span: Span,
         pub value: Number,
     }
@@ -491,7 +491,7 @@ define!({
 
     pub enum KeyframeSelector {
         Ident(Ident),
-        Percent(Percent),
+        Percentage(Percentage),
     }
 
     pub struct LayerName {
